==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/ga.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Ní féidir leat do chead léite féin a bhaint.",
    "Team folders" : "Fillteáin foirne",
    "Admin configured folders shared with everyone in a team" : "Fillteáin cumraithe ag an riarthóir a roinntear le gach duine i bhfoireann",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Fillteáin cumraithe ag an riarthóir a roinntear le gach duine i bhfoireann.\n\nIs féidir fillteáin a chumrú ó *Fillteáin Foirne* sna socruithe riaracháin.\n\nTar éis fillteán a chruthú, is féidir leis an riarthóir rochtain ar an bhfillteán a thabhairt d’fhoireann amháin nó níos mó, a gceadanna scríofa/roinnte a rialú agus cuóta a shannadh don fhillteán.\nÓn Mol 10/Nextcloud 31, ní mór don riarthóir a bheith mar chuid den fhoireann le go mbeidh sé in ann fillteán Foirne a shannadh dó.",
    "Unset" : "Díshocraithe",
    "Denied (Inherited permission)" : "Diúltaithe (cead oidhreachta)",
    "Allowed (Inherited permission)" : "Ceadaithe (cead oidhreachta)",
    "Denied" : "Diúltaíodh",
    "Allowed" : "Ceadaithe",
    "Access denied" : "Rochtain diúltaithe",
    "Access allowed" : "Ceadaíodh rochtain",
    "Inherit permission" : "Cead oidhreachta",
    "Deny" : "shéanadh",
    "Allow" : "Ceadaigh",
    "Group" : "Grúpa",
    "Team" : "Foireann",
    "Team folder" : "Fillteán foirne",
    "Read" : "Léigh",
    "Write" : "Scríobh",
    "Create" : "Cruthaigh",
    "Delete" : "Scrios",
    "Share" : "Comhroinn",
    "You" : "tú",
    "Remove access rule" : "Bain an riail rochtana",
    "Add advanced permission rule" : "Cuir riail cheada chun cinn leis",
    "Select a user or group" : "Roghnaigh úsáideoir nó grúpa",
    "Open Team folder" : "Oscail fillteán Foirne",
    "Permission denied. User does not have sufficient permissions." : "Cead diúltaithe. Níl go leor ceadanna ag an úsáideoir.",
    "Unexpected status from server" : "Stádas gan choinne ón bhfreastalaí",
    "List of Team folders." : "Liosta fillteáin Foirne.",
    "No Team folders yet" : "Níl aon fhillteán Foirne fós",
    "Team folders will show up here" : "Taispeánfar fillteáin foirne anseo",
    "Add group" : "Cuir grúpa leis",
    "Default" : "Réamhshocrú",
    "Unlimited" : "Gan teorainn",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "An bhfuil tú cinnte gur mhaith leat \"{folderName}\" agus gach comhad istigh a scriosadh? Ní féidir an oibríocht seo a chealú",
    "Delete \"{folderName}\"?" : "An bhfuil fonn ort \"{folderName}\" a scriosadh?",
    "Team folder admin delegation" : "Tarmligean riarthóir fillteán foirne",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Ligeann Nextcloud duit riarachán fillteán Foirne a tharmligean chuig úsáideoirí nach riarthóirí iad.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Sonraigh thíos na grúpaí a mbeidh cead acu fillteáin Foirne a bhainistiú agus a API/REST a úsáid.",
    "They will have access to all Team folders." : "Beidh rochtain acu ar gach fillteán Foirne.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Sonraigh thíos na grúpaí a mbeidh cead acu fillteáin Foirne a bhainistiú agus a API/REST amháin a úsáid.",
    "They will only have access to Team folders for which they have advanced permissions." : "Ní bheidh rochtain acu ach ar fhillteáin Foirne a bhfuil ardcheadanna acu ina leith.",
    "Group or team" : "Grúpa nó foireann",
    "Sort by number of groups or teams that have access to this folder" : "Sórtáil de réir líon na ngrúpaí nó na bhfoirne a bhfuil rochtain acu ar an bhfillteán seo",
    "Sort by number of groups that have access to this folder" : "Sórtáil de réir líon na ngrúpaí a bhfuil rochtain acu ar an bhfillteán seo",
    "Folder name" : "Ainm fillteáin",
    "Quota" : "Cuóta",
    "Advanced Permissions" : "Ceadanna Casta",
    "Pagination of team folders" : "Leathanachú fillteán foirne",
    "Previous" : "Roimhe Seo",
    "Next" : "Ar aghaidh",
    "User" : "Úsáideoir",
    "Unknown" : "Anaithnid",
    "Users/groups that can manage" : "Úsáideoirí/grúpaí is féidir a bhainistiú",
    "None" : "aon cheann",
    "No other groups or teams available" : "Níl aon ghrúpa nó foirne eile ar fáil",
    "No other groups available" : "Níl aon ghrúpa eile ar fáil",
    "{displayName} (team)" : "{displayName} (foireann)",
    "Add group or team" : "Cuir grúpa nó foireann leis",
    "{size} used" : "{size} in úsáid",
    "Other …" : "Eile …",
    "You can not remove your own read permission." : "Ní féidir leat do chead léite féin a bhaint.",
    "Group folders" : "Fillteáin ghrúpa",
    "Admin configured folders shared with everyone in a group" : "Fillteáin cumraithe ag an riarthóir roinnte le gach duine i ngrúpa",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Fillteáin cumraithe ag an riarthóir roinnte le gach duine i ngrúpa.\n\nIs féidir fillteáin a chumrú ó *Fillteáin Ghrúpa* sna socruithe riaracháin.\n\nTar éis fillteán a chruthú, is féidir leis an riarthóir rochtain ar an bhfillteán a thabhairt do ghrúpa amháin nó níos mó, a gceadanna scríofa/roinnte a rialú agus cuóta a shannadh don fhillteán.",
    "Group folder" : "Fillteán grúpa",
    "Open group folder" : "Oscail fillteán grúpa",
    "List of group folders." : "Liosta fillteán grúpa.",
    "No group folders yet" : "Níl aon fhillteáin ghrúpa fós",
    "Group folders will show up here" : "Taispeánfar fillteáin ghrúpa anseo",
    "Group folder admin delegation" : "Grúpáil tarmligean riaracháin fillteán",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Ligeann Nextcloud duit riarachán fillteán grúpa a tharmligean chuig úsáideoirí nach riarthóirí iad.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Sonraigh thíos na grúpaí a mbeidh cead acu fillteáin ghrúpa a bhainistiú agus a API/REST a úsáid.",
    "They will have access to all group folders." : "Beidh rochtain acu ar gach fillteán grúpa.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Sonraigh thíos na grúpaí a mbeidh cead acu fillteáin ghrúpa a bhainistiú agus a API/REST amháin a úsáid.",
    "They will only have access to group folders for which they have advanced permissions." : "Ní bheidh rochtain acu ach ar fhillteáin ghrúpa a bhfuil ceadanna chun cinn acu ina leith.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Fillteáin cumraithe ag an riarthóir a roinntear le gach duine i bhfoireann.\n\nIs féidir fillteáin a chumrú ó *Fillteáin Foirne* sna socruithe riaracháin.\n\nTar éis fillteán a chruthú, is féidir leis an riarthóir rochtain ar an bhfillteán a thabhairt d’fhoireann amháin nó níos mó, a gceadanna scríofa/roinnte a rialú agus cuóta a shannadh don fhillteán."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/ga.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Ní féidir leat do chead léite féin a bhaint.",
    "Team folders" : "Fillteáin foirne",
    "Unset" : "Díshocraithe",
    "Denied (Inherited permission)" : "Diúltaithe (cead oidhreachta)",
    "Allowed (Inherited permission)" : "Ceadaithe (cead oidhreachta)",
    "Denied" : "Diúltaíodh",
    "Allowed" : "Ceadaithe",
    "Access denied" : "Rochtain diúltaithe",
    "Access allowed" : "Ceadaíodh rochtain",
    "Inherit permission" : "Cead oidhreachta",
    "Deny" : "shéanadh",
    "Allow" : "Ceadaigh",
    "Group" : "Grúpa",
    "Team" : "Foireann",
    "Team folder" : "Fillteán foirne",
    "Read" : "Léigh",
    "Write" : "Scríobh",
    "Create" : "Cruthaigh",
    "Delete" : "Scrios",
    "Share" : "Comhroinn",
    "You" : "tú",
    "Remove access rule" : "Bain an riail rochtana",
    "Add advanced permission rule" : "Cuir riail cheada chun cinn leis",
    "Select a user or group" : "Roghnaigh úsáideoir nó grúpa",
    "Open Team folder" : "Oscail fillteán Foirne",
    "Permission denied. User does not have sufficient permissions." : "Cead diúltaithe. Níl go leor ceadanna ag an úsáideoir.",
    "Unexpected status from server" : "Stádas gan choinne ón bhfreastalaí",
    "List of Team folders." : "Liosta fillteáin Foirne.",
    "No Team folders yet" : "Níl aon fhillteán Foirne fós",
    "Team folders will show up here" : "Taispeánfar fillteáin foirne anseo",
    "Add group" : "Cuir grúpa leis",
    "Default" : "Réamhshocrú",
    "Unlimited" : "Gan teorainn",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "An bhfuil tú cinnte gur mhaith leat \"{folderName}\" agus gach comhad istigh a scriosadh? Ní féidir an oibríocht seo a chealú",
    "Delete \"{folderName}\"?" : "An bhfuil fonn ort \"{folderName}\" a scriosadh?",
    "Team folder admin delegation" : "Tarmligean riarthóir fillteán foirne",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Ligeann Nextcloud duit riarachán fillteán Foirne a tharmligean chuig úsáideoirí nach riarthóirí iad.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Sonraigh thíos na grúpaí a mbeidh cead acu fillteáin Foirne a bhainistiú agus a API/REST a úsáid.",
    "They will have access to all Team folders." : "Beidh rochtain acu ar gach fillteán Foirne.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Sonraigh thíos na grúpaí a mbeidh cead acu fillteáin Foirne a bhainistiú agus a API/REST amháin a úsáid.",
    "They will only have access to Team folders for which they have advanced permissions." : "Ní bheidh rochtain acu ach ar fhillteáin Foirne a bhfuil ardcheadanna acu ina leith.",
    "Group or team" : "Grúpa nó foireann",
    "Sort by number of groups or teams that have access to this folder" : "Sórtáil de réir líon na ngrúpaí nó na bhfoirne a bhfuil rochtain acu ar an bhfillteán seo",
    "Sort by number of groups that have access to this folder" : "Sórtáil de réir líon na ngrúpaí a bhfuil rochtain acu ar an bhfillteán seo",
    "Folder name" : "Ainm fillteáin",
    "Quota" : "Cuóta",
    "Advanced Permissions" : "Ceadanna Casta",
    "Pagination of team folders" : "Leathanachú fillteán foirne",
    "Previous" : "Roimhe Seo",
    "Next" : "Ar aghaidh",
    "User" : "Úsáideoir",
    "Unknown" : "Anaithnid",
    "Users/groups that can manage" : "Úsáideoirí/grúpaí is féidir a bhainistiú",
    "None" : "aon cheann",
    "No other groups or teams available" : "Níl aon ghrúpa nó foirne eile ar fáil",
    "No other groups available" : "Níl aon ghrúpa eile ar fáil",
    "{displayName} (team)" : "{displayName} (foireann)",
    "Add group or team" : "Cuir grúpa nó foireann leis",
    "{size} used" : "{size} in úsáid",
    "Other …" : "Eile …",
    "You can not remove your own read permission." : "Ní féidir leat do chead léite féin a bhaint.",
    "Group folders" : "Fillteáin ghrúpa",
    "Admin configured folders shared with everyone in a group" : "Fillteáin cumraithe ag an riarthóir roinnte le gach duine i ngrúpa",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Fillteáin cumraithe ag an riarthóir roinnte le gach duine i ngrúpa.\n\nIs féidir fillteáin a chumrú ó *Fillteáin Ghrúpa* sna socruithe riaracháin.\n\nTar éis fillteán a chruthú, is féidir leis an riarthóir rochtain ar an bhfillteán a thabhairt do ghrúpa amháin nó níos mó, a gceadanna scríofa/roinnte a rialú agus cuóta a shannadh don fhillteán.",
    "Group folder" : "Fillteán grúpa",
    "Open group folder" : "Oscail fillteán grúpa",
    "List of group folders." : "Liosta fillteán grúpa.",
    "No group folders yet" : "Níl aon fhillteáin ghrúpa fós",
    "Group folders will show up here" : "Taispeánfar fillteáin ghrúpa anseo",
    "Group folder admin delegation" : "Grúpáil tarmligean riaracháin fillteán",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Ligeann Nextcloud duit riarachán fillteán grúpa a tharmligean chuig úsáideoirí nach riarthóirí iad.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Sonraigh thíos na grúpaí a mbeidh cead acu fillteáin ghrúpa a bhainistiú agus a API/REST a úsáid.",
    "They will have access to all group folders." : "Beidh rochtain acu ar gach fillteán grúpa.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Sonraigh thíos na grúpaí a mbeidh cead acu fillteáin ghrúpa a bhainistiú agus a API/REST amháin a úsáid.",
    "They will only have access to group folders for which they have advanced permissions." : "Ní bheidh rochtain acu ach ar fhillteáin ghrúpa a bhfuil ceadanna chun cinn acu ina leith.",
    "Admin configured folders shared with everyone in a team" : "Fillteáin cumraithe ag an riarthóir a roinntear le gach duine i bhfoireann",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Fillteáin cumraithe ag an riarthóir a roinntear le gach duine i bhfoireann.\n\nIs féidir fillteáin a chumrú ó *Fillteáin Foirne* sna socruithe riaracháin.\n\nTar éis fillteán a chruthú, is féidir leis an riarthóir rochtain ar an bhfillteán a thabhairt d’fhoireann amháin nó níos mó, a gceadanna scríofa/roinnte a rialú agus cuóta a shannadh don fhillteán.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Fillteáin cumraithe ag an riarthóir a roinntear le gach duine i bhfoireann.\n\nIs féidir fillteáin a chumrú ó *Fillteáin Foirne* sna socruithe riaracháin.\n\nTar éis fillteán a chruthú, is féidir leis an riarthóir rochtain ar an bhfillteán a thabhairt d’fhoireann amháin nó níos mó, a gceadanna scríofa/roinnte a rialú agus cuóta a shannadh don fhillteán.\nÓn Mol 10/Nextcloud 31, ní mór don riarthóir a bheith mar chuid den fhoireann le go mbeidh sé in ann fillteán Foirne a shannadh dó."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
